# blahblah

[![Codecov](https://img.shields.io/codecov/c/github/d42-schemas/blahblah/master.svg?style=flat-square)](https://codecov.io/gh/d42-schemas/blahblah)
[![PyPI](https://img.shields.io/pypi/v/blahblah.svg?style=flat-square)](https://pypi.python.org/pypi/blahblah/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/blahblah?style=flat-square)](https://pypi.python.org/pypi/blahblah/)
[![Python Version](https://img.shields.io/pypi/pyversions/blahblah.svg?style=flat-square)](https://pypi.python.org/pypi/blahblah/)

`blahblah` is a package designed for generating fake data based on the [district42](https://github.com/d42-schemas/district42) schemas. It provides a simple and flexible way to generate test data for your applications.

This package is part of the [d42 package](https://pypi.org/project/d42/). For a quick-start guide and detailed documentation, please visit the official documentation at [d42.vedro.io/docs/quick-start](https://d42.vedro.io/docs/quick-start)
